@@ -10,6 +10,8 @@ from ..scene.scene import Scene, append_scenes
 from ..constants import log_time, log
 
 from . import misc
+
+from .xyz import _xyz_loaders
 from .ply import _ply_loaders
 from .stl import _stl_loaders
 from .dae import _collada_loaders
@@ -17,12 +19,12 @@ from .obj import _obj_loaders
 from .off import _off_loaders
 from .misc import _misc_loaders
 from .gltf import _gltf_loaders
+from .xaml import _xaml_loaders
+from .binvox import _binvox_loaders
 from .assimp import _assimp_loaders
 from .threemf import _three_loaders
 from .openctm import _ctm_loaders
-from .xml_based import _xml_loaders
-from .binvox import _binvox_loaders
-from .xyz import _xyz_loaders
+from .threedxml import _threedxml_loaders
 
 
 try:
@@ -37,13 +39,13 @@ except BaseException as E:
 
 def mesh_formats():
     """
-    Get a list of mesh formats
+    Get a list of mesh formats available to load.
 
     Returns
     -----------
     loaders : list
-        Extensions of available mesh loaders
-        i.e. 'stl', 'ply', etc.
+      Extensions of available mesh loaders,
+      i.e. 'stl', 'ply', etc.
     """
     return list(mesh_loaders.keys())
 
@@ -207,7 +209,6 @@ def load_mesh(file_obj,
                                           file_type=file_type,
                                           resolver=resolver,
                                           **kwargs)
-
         if not isinstance(results, list):
             results = [results]
 
@@ -294,29 +295,43 @@ def load_compressed(file_obj,
             else:
                 available = mesh_formats()
 
+        meta_archive = {}
         for name, data in files.items():
-            # only load formats that we support
-            compressed_type = util.split_extension(name).lower()
-            if compressed_type not in available:
-                # don't raise an exception, just try the next one
-                continue
-            # store the file name relative to the archive
-            metadata['file_name'] = (archive_name + '/' +
-                                     os.path.basename(name))
-            # load the individual geometry
-            loaded = load(file_obj=data,
-                          file_type=compressed_type,
-                          resolver=resolver,
-                          metadata=metadata,
-                          **kwargs)
+            try:
+                # only load formats that we support
+                compressed_type = util.split_extension(name).lower()
 
-            # some loaders return multiple geometries
-            if util.is_sequence(loaded):
-                # if the loader has returned a list of meshes
-                geometries.extend(loaded)
-            else:
-                # if the loader has returned a single geometry
-                geometries.append(loaded)
+                # if file has metadata type include it
+                if compressed_type in 'yaml':
+                    import yaml
+                    meta_archive[name] = yaml.safe_load(data)
+                elif compressed_type in 'json':
+                    import json
+                    meta_archive[name] = json.loads(data)
+
+                if compressed_type not in available:
+                    # don't raise an exception, just try the next one
+                    continue
+                # store the file name relative to the archive
+                metadata['file_name'] = (archive_name + '/' +
+                                         os.path.basename(name))
+                # load the individual geometry
+                loaded = load(file_obj=data,
+                              file_type=compressed_type,
+                              resolver=resolver,
+                              metadata=metadata,
+                              **kwargs)
+
+                # some loaders return multiple geometries
+                if util.is_sequence(loaded):
+                    # if the loader has returned a list of meshes
+                    geometries.extend(loaded)
+                else:
+                    # if the loader has returned a single geometry
+                    geometries.append(loaded)
+            except BaseException:
+                log.debug('failed to load file in zip',
+                          exc_info=True)
 
     finally:
         # if we opened the file in this function
@@ -327,6 +342,10 @@ def load_compressed(file_obj,
     # append meshes or scenes into a single Scene object
     result = append_scenes(geometries)
 
+    # append any archive metadata files
+    if isinstance(result, Scene):
+        result.metadata.update(meta_archive)
+
     return result
 
 
@@ -625,11 +644,12 @@ mesh_loaders.update(_misc_loaders)
 mesh_loaders.update(_stl_loaders)
 mesh_loaders.update(_ctm_loaders)
 mesh_loaders.update(_ply_loaders)
-mesh_loaders.update(_xml_loaders)
 mesh_loaders.update(_obj_loaders)
 mesh_loaders.update(_off_loaders)
 mesh_loaders.update(_collada_loaders)
 mesh_loaders.update(_gltf_loaders)
+mesh_loaders.update(_xaml_loaders)
+mesh_loaders.update(_threedxml_loaders)
 mesh_loaders.update(_three_loaders)
 mesh_loaders.update(_xyz_loaders)
 
