@@ -20,7 +20,7 @@ class SceneGraph(object):
 
     def __init__(self, base_frame='world'):
         """
-        Create a scene graph, holding homogenous transformation
+        Create a scene graph, holding homogeneous transformation
         matrices and instance information about geometry.
 
         Parameters
@@ -136,7 +136,7 @@ class SceneGraph(object):
             # parent -> child -> child
             path = self.transforms.shortest_path(
                 frame_from, frame_to)
-            # collect a homogenous transform for each edge
+            # collect a homogeneous transform for each edge
             matrices = [edge_data[(u, v)]['matrix'] for u, v in
                         zip(path[:-1], path[1:])]
             # multiply matrices into single transform
@@ -338,6 +338,43 @@ class SceneGraph(object):
                 raise ValueError(
                     'edge incorrect shape: %s', str(edge))
 
+    def to_networkx(self):
+        """
+        Return a `networkx` copy of this graph.
+
+        Returns
+        ----------
+        graph : networkx.DiGraph
+          Directed graph.
+        """
+        import networkx
+        return networkx.from_edgelist(
+            self.to_edgelist(),
+            create_using=networkx.DiGraph)
+
+    def show(self, **kwargs):
+        """
+        Plot the scene graph using `networkx.draw_networkx`
+        which uses matplotlib to display the graph.
+
+        Parameters
+        -----------
+        kwargs : dict
+          Passed to `networkx.draw_networkx`
+        """
+        import networkx
+        import matplotlib.pyplot as plt
+        # default kwargs will only be set if not
+        # passed explicitly to the show command
+        defaults = {'with_labels': True}
+        kwargs.update(**{k: v for k, v in defaults.items()
+                         if k not in kwargs})
+        networkx.draw_networkx(
+            G=self.to_networkx(),
+            **kwargs)
+
+        plt.show()
+
     def load(self, edgelist):
         """
         Load transform data from an edge list into the current
@@ -506,9 +543,47 @@ class EnforcedForest(object):
 
         return True
 
+    def remove_node(self, u):
+        """
+        Remove a node from the forest.
+
+        Parameters
+        -----------
+        u : any
+          Hashable node key.
+
+        Returns
+        --------
+        changed : bool
+          Return if this operation changed anything.
+        """
+        # check if node is part of forest
+        if u not in self.node_data:
+            return False
+
+        # topology will change so clear cache
+        self._cache = {}
+
+        # delete all children's references and parent reference
+        children = [child for (child, parent) in self.parents.items() if parent == u]
+        for c in children:
+            del self.parents[c]
+        if u in self.parents:
+            del self.parents[u]
+
+        # delete edge data
+        edges = [(a, b) for (a, b) in self.edge_data if a == u or b == u]
+        for e in edges:
+            del self.edge_data[e]
+
+        # delete node data
+        del self.node_data[u]
+
+        return True
+
     def shortest_path(self, u, v):
         """
-        Find the shortest path beween `u` and `v`.
+        Find the shortest path between `u` and `v`.
 
         Note that it will *always* be ordered from
         root direction to leaf direction, so `u` may
@@ -638,18 +713,18 @@ def kwargs_to_matrix(
         **kwargs):
     """
     Take multiple keyword arguments and parse them
-    into a homogenous transformation matrix.
+    into a homogeneous transformation matrix.
 
     Returns
     ---------
     matrix : (4, 4) float
-      Homogenous transformation matrix.
+      Homogeneous transformation matrix.
     """
     if matrix is not None:
         # a matrix takes immediate precedence over other options
         return np.array(matrix, dtype=np.float64)
     elif quaternion is not None:
-        result = transformations.quaternion_matrix(quaternion)
+        matrix = transformations.quaternion_matrix(quaternion)
     elif axis is not None and angle is not None:
         matrix = transformations.rotation_matrix(angle, axis)
     else:
@@ -658,6 +733,6 @@ def kwargs_to_matrix(
     if translation is not None:
         # translation can be used in conjunction with any
         # of the methods specifying transforms
-        result[:3, 3] += translation
+        matrix[:3, 3] += translation
 
-    return result
+    return matrix
